@@ -1,4 +1,4 @@
-from os import path
+import posixpath
 from typing import (
     Any,
     Callable,
@@ -37,7 +37,7 @@ def _next_path(current_path: str) -> Callable[[str], str]:
     """
 
     def _wrap(segment: str):
-        return path.join(current_path, segment)
+        return posixpath.join(current_path, segment)
 
     return _wrap
 
